Module: Google::Cloud::Memorystore
- Defined in:
- lib/google/cloud/memorystore.rb,
lib/google/cloud/memorystore/version.rb
Constant Summary collapse
- VERSION =
"1.2.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.memorystore| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-memorystore library.
-
.memorystore(version: :v1, &block) ⇒ ::Object
Create a new client object for Memorystore.
-
.memorystore_available?(version: :v1) ⇒ boolean
Determines whether the Memorystore service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.memorystore| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-memorystore library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
137 138 139 140 141 |
# File 'lib/google/cloud/memorystore.rb', line 137 def self.configure yield ::Google::Cloud.configure.memorystore if block_given? ::Google::Cloud.configure.memorystore end |
.memorystore(version: :v1, &block) ⇒ ::Object
Create a new client object for Memorystore.
By default, this returns an instance of
Google::Cloud::Memorystore::V1::Memorystore::Rest::Client
for a REST client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Memorystore service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the Memorystore service. You can determine whether the method will succeed by calling memorystore_available?.
About Memorystore
Service describing handlers for resources
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/google/cloud/memorystore.rb', line 71 def self.memorystore version: :v1, &block require "google/cloud/memorystore/#{version.to_s.downcase}" package_name = Google::Cloud::Memorystore .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Memorystore.const_get(package_name).const_get(:Memorystore) service_module.const_get(:Rest).const_get(:Client).new(&block) end |
.memorystore_available?(version: :v1) ⇒ boolean
Determines whether the Memorystore service is supported by the current client. If true, you can retrieve a client object by calling memorystore. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Memorystore service, or if the versioned client gem needs an update to support the Memorystore service.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/google/cloud/memorystore.rb', line 93 def self.memorystore_available? version: :v1 require "google/cloud/memorystore/#{version.to_s.downcase}" package_name = Google::Cloud::Memorystore .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Memorystore.const_get package_name return false unless service_module.const_defined? :Memorystore service_module = service_module.const_get :Memorystore return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest service_module.const_defined? :Client rescue ::LoadError false end |